"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.api_client import ApiClient, Endpoint as _Endpoint
from unicourt.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from unicourt.model.case_search_response import CaseSearchResponse
from unicourt.model.exception import Exception


class CaseSearchApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.search_cases_endpoint = _Endpoint(
            settings={
                'response_type': (CaseSearchResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseSearch',
                'operation_id': 'search_cases',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'q',
                    'sort',
                    'order',
                    'page_number',
                ],
                'required': [
                    'q',
                ],
                'nullable': [
                ],
                'enum': [
                    'sort',
                    'order',
                ],
                'validation': [
                    'q',
                    'sort',
                    'order',
                    'page_number',
                ]
            },
            root_map={
                'validations': {
                    ('q',): {
                        'max_length': 2000,
                        'min_length': 3,
                    },
                    ('sort',): {
                        'max_length': 9,
                        'min_length': 9,
                    },
                    ('order',): {
                        'max_length': 4,
                        'min_length': 3,
                    },
                    ('page_number',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {

                        "FILEDDATE": "filedDate",
                        "RELEVANCY": "relevancy"
                    },
                    ('order',): {

                        "ASC": "asc",
                        "DESC": "desc"
                    },
                },
                'openapi_types': {
                    'q':
                        (str,),
                    'sort':
                        (str,),
                    'order':
                        (str,),
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'q': 'q',
                    'sort': 'sort',
                    'order': 'order',
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'q': 'query',
                    'sort': 'query',
                    'order': 'query',
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.search_cases_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (CaseSearchResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseSearch/{caseSearchId}',
                'operation_id': 'search_cases_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_search_id',
                    'page_number',
                ],
                'required': [
                    'case_search_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_search_id',
                    'page_number',
                ]
            },
            root_map={
                'validations': {
                    ('case_search_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                    ('page_number',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_search_id':
                        (str,),
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'case_search_id': 'caseSearchId',
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'case_search_id': 'path',
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def search_cases(
        self,
        q,
        **kwargs
    ):
        """Case search.  # noqa: E501

        This endpoint retrieves cases according to keyword expressions you provide. <br> Keyword expressions are constructed according to the rules described below. <br><br> This API supports multiple use cases:    - Search for multiple keywords  `Google OR Facebook`.   - Search within particular attributes.   - Relational search using terms and connectors.   - And much more. ----  ## Allowed Connectors in Keyword Expressions | Connector | Description  | Example | | ------| ------|------| | **AND** |Find cases containing each of the terms joined by AND connectors.|**personal AND injury**| | **OR**  |Find cases containing any of the terms joined by OR connectors.|**order OR decision**| | **NOT** |Find cases that do not contain the specified term.|**personal AND NOT injury**.  Find cases with the word “personal” and not “injury”.| | **“[phrase]”** |Find the exact phrase placed between the quotation marks.|**\"personal injury”**| | **~**  |Find cases in which the specified words appear near each other. For example, \"personal injury\" ~ 5 targets cases in which the word \"personal\" appears within 5 words of the word \"injury\".|**“personal injury” ~ 5** - Find cases with “personal” within five words of “injury”. | | **( … )** |Specifies the order in which connectors are to be appliied in a keyword expression.| **personal AND (injury OR fall)** - Find cases with the word personal injury or personal fall.|  <br><br> ## Fields and Connectors Searching | Filed | Description  | Example | | ------| ------|------| |**caseNumber** |Find cases with the specified case number (i.e., docket number).| **caseNumber:\"2020-L-007212\"** - Find cases whose case number matches given case number number.| |**caseName** |Find cases with the specified case title.| **caseName:\"THOMAS P. CARNEY, INC. VS BEHLER JAMES Et Al\"** - Find cases whose case name matches given terms.| |**Court**|Find cases in the specified court.|**(Court:(name:(New York)))** - Find cases in New York state.<br>| |**CaseStatus**|Find cases witih the specified case status.|**(CaseStatus:(name:Disposed))** - All disposed cases.<br>| |**CaseType**|Find cases of the specified case type. | **(CaseType:(name:Property))** - Cases with case type “property”.| |**Party** | Find cases involving the specified party.| **(Party:(name:Apple))** - Find cases involving Apple. | |**partyId**|Find cases involving a party with the specified partyId value.|**(Party:(partyId:\"PRTYgu1ffe866484c2\"))**| |**PartyRole** | Find cases in which at least one party has the specified party role. | **(Party:((PartyRole:(name:\"plaintiff\"))))** - Find cases with party role “plaintiff”.<br><br> **(Party:((PartyRole:(name:defendant)) AND (AttorneyRepresentationType:(name:(Attorney represented)))))** - Find cases where a party is acting as defendant and represented by an attorney.| |**AttorneyRepresentationType**| Find cases in which at least one party has the specified attorney representation type.|**(Party:(AttorneyRepresentationType:(name:\"attorney represented\")))** - Find cases where a party is represented by an attorney. | |**Attorney** | Find cases involving the specified attorney. | **(Attorney:(name:\"David Boies\"))** - Find cases involving the attorney David Boies. | |**AttorneyType**|Find cases involving at least one attorney of the specified attorney type.|**(Attorney:((AttorneyType:(name:\"Lead Attorney\"))))**| |**Judge** |Find cases involving the specified judge. | **(Judge:(name:\"Posner\"))** - Find cases involving Judge Posner.| |**JudgeType**|Find cases involving at least one judge of the specified judge type.|**(Judge:((JudgeType:(name:\"Magistrate\"))))**| |**CaseStats**|Find cases with the specified case statistics.|**(CaseStats:(partyCount:[10 TO 100]))** - Find cases involving 10 to 100 parties.<br>**(CaseStats:(attorneyCount:[2 TO 40]))** - Find cases involving 2 to 40 attorneys.<br>**(CaseStats:(judgeCount:[\\* TO 2]))** - Find cases involving up to 2 judges. <br>**(CaseStats:(docketEntryCount:[10 TO 100]))** - Find cases having 10 to 100 docket_entries. <br>**(CaseStats:(allCaseDocumentCount:[10 TO 100]))** - Find cases having 10 to 100 documents. | |**filedDate** | Find cases that were filed on the specified date or within the specified date range. | **filedDate:[2020-03-15T00:00:00 TO 2021-12-01T00:00:00]** - Find the most recently filed cases between March 15, 2020 and December 1, 2021 (inclusive). | |**lastFetchDate**| Find cases in which UniCourt last checked for updates on the specified date or within the specified date range. |**(lastFetchDate:[now-60d TO \\*\\])** - Find cases that were updated by UniCourt in the last 60 days. | |**lastFetchDateWithUpdates**|Find cases in which UniCourt last detected an update on the specified date or within the specified date range.|**(lastFetchDateWithUpdates:[now-6d TO \\*\\])** - Find cases for the changes found on court site in last 6 days.| |**participantsLastFetchDate**|Find cases in which information cocnerning participants was last updated on the specified date or within the specified date range.|**(participantsLastFetchDate:[now-6d TO \\*\\])** - Find cases where the participant's information was updated in last 6 days.| |**DocketEntry**|Find cases in which at least one docket entry contains the specified text.|**(DocketEntry:(text:(Motion to Compel Responses) AND docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00]))** - Find cases with docket text “Motion to Compel Responses” and action date between 2020-01-01 and 2020-05-01.| |**docketEntryDate**|Find cases in which at least one docket entry was made on the specified date or within the specified date range.|**(DocketEntry:(docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00])) AND (CaseStats:(allCaseDocumentCount:[0 TO 10]))** - Find cases with docket action date between 2020-01-01 and 2020-05-01 having up to 10 documents associated with it.| |**HearingDate**| Find cases with at least one hearing scheduled for the specified date or within the specified date range.|**(Hearing:(hearingDate:[now TO now+10d]))** - Find cases where hearing is scheduled in next 10 days.| |**HearingDate**| Search for cases where hearing is going to happen in 10 to 20days.|**(Hearing:(hearingDate:[now+10d TO now+20d]))** - Find cases where hearing is scheduled in next 10 to 20 days.| |**JurisdictionGeo**|Find cases in which the law of the specified state governs.|**(JurisdictionGeo:(state:\"New York\"))**- Find cases where Jurisdiction is New York state.| |**Party Address Exists**|Find cases with Party addresses.|**(Party:(Contact:(Address:(stateName:\\*))))**- Returns only those cases that have addresses for parties.| |**Document**|Find cases with specific document name and preview is available for the document.|**(CaseDocument:(name:\"civil case cover sheet\" AND isPreviewAvailable:true))**- Returns cases with document civil case cover sheet and preview is available.|  <br><br> --- ## Party Sub Filter Examples |Example |Explanation | |---|---| |**(Party:(name:google AND (PartyRole:(name:\"plaintiff\"))))**|Find cases involving at least one plaintiff whose name contains the term \"Google\".| |**(Party:(name:\"OTELIA PEREIDA\" AND (AttorneyRepresentationType:(name:\"Attorney represented\")))) AND (Attorney:(name:\"Law Offices of Todd M Friedman\"))**|Find cases where the Party is *OTELIA PEREIDA* and is represented by the attorney *Law Offices of Todd M Friedman*.|  --- ### All query parameters supported for this API can be found in below schema section. Schema -->  CaseSearchQueryObject   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_cases(q, async_req=True)
        >>> result = thread.get()

        Args:
            q (str): Query parameter for keyword expressions.</a> 

        Keyword Args:
            sort (str): Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.. [optional] if omitted the server will use the default value of "filedDate"
            order (str): Query parameter specifying whether search result are sorted in ascending or descending order.. [optional] if omitted the server will use the default value of "desc"
            page_number (int): The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseSearchResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['q'] = \
            q
        return self.search_cases_endpoint.call_with_http_info(**kwargs)

    def search_cases_by_id(
        self,
        case_search_id,
        **kwargs
    ):
        """Case search results for a given caseSearchId.  # noqa: E501

        Retrieve the search results corresponding to the specified caseSearchId value.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_cases_by_id(case_search_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_search_id (str): Case Search information for the given caseSearchId.

        Keyword Args:
            page_number (int): The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseSearchResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_search_id'] = \
            case_search_id
        return self.search_cases_by_id_endpoint.call_with_http_info(**kwargs)




from unicourt.api.pacer_api import PACERApi
from unicourt import utils
class PACER:

    @staticmethod
    def all_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search all courts within the PACER system for a particular case.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).all_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def all_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for the specified party across all PACER case filings.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).all_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def appeal_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for PACER cases filed in U.S. Courts of Appeals.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).appeal_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def appeal_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for the specified party across all PACER appeals cases.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).appeal_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def bankruptcy_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for Bankruptcy Courts.  


        Search for PACER cases filed in U.S. Bankruptcy Courts.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).bankruptcy_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def bankruptcy_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for the specified party in PACER bankruptcy filings.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).bankruptcy_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def civil_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for civil cases filed in PACER.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).civil_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def civil_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for the specified party in civil cases filed in PACER.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).civil_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def criminal_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for criminal cases in PACER.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).criminal_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def criminal_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for the specified party in PACER criminal cases.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).criminal_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def import_pacer_case_by_court_using_case_number(
        pacer_user_id,
        pacer_client_code,
        case_number,
        court_id,
        **kwargs
    ):

        """Find PACER Case for a requested Case Number and Court.  


        Import the specified case from PACER.    Workflow:     1.This API will return the Find Case results from the court site in a form of array of UniCourt Case Objects. These case objects will consists only Meta information of the case if not already present in the UniCourt Database.     2.To get the full updated case information one will have to request the caseUpdate API by passing the caseId.    Note:     1.Charges for Find Case in District, Bankruptcy and National Courts is free. Find case for Appeal Courts will be charged at minimum rate of $0.1. The fee charged by the court for find case can be found in the response of this API in the field courtFee.     2.The results of the search has less Meta information in case objects compared to the Meta information of cases found using the PCL search APIs.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).import_pacer_case_by_court_using_case_number(
        pacer_user_id,
        pacer_client_code,
        case_number,
        court_id,
        **kwargs
    )

    @staticmethod
    def multi_district_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for multidistrict litigation in PACER.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).multi_district_courts_pacer_case_locator_case_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )

    @staticmethod
    def multi_district_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    ):

        """PACER Case Locator Search API for All Courts.  


        Search for the specified party in multidistrict litigation in PACER.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERApi(api_client).multi_district_courts_pacer_case_locator_party_search(
        pacer_user_id,
        pacer_client_code,
        **kwargs
    )



"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from unicourt.exceptions import ApiAttributeError


def lazy_import():
    from unicourt.model.attorneys import Attorneys
    from unicourt.model.case_cause_of_action import CaseCauseOfAction
    from unicourt.model.case_charge import CaseCharge
    from unicourt.model.case_documents import CaseDocuments
    from unicourt.model.case_stats import CaseStats
    from unicourt.model.case_status import CaseStatus
    from unicourt.model.case_type import CaseType
    from unicourt.model.court import Court
    from unicourt.model.court_location import CourtLocation
    from unicourt.model.docket_entries import DocketEntries
    from unicourt.model.hearings import Hearings
    from unicourt.model.judges import Judges
    from unicourt.model.parties import Parties
    from unicourt.model.related_cases import RelatedCases
    from unicourt.model.source_case_data import SourceCaseData
    globals()['Attorneys'] = Attorneys
    globals()['CaseCauseOfAction'] = CaseCauseOfAction
    globals()['CaseCharge'] = CaseCharge
    globals()['CaseDocuments'] = CaseDocuments
    globals()['CaseStats'] = CaseStats
    globals()['CaseStatus'] = CaseStatus
    globals()['CaseType'] = CaseType
    globals()['Court'] = Court
    globals()['CourtLocation'] = CourtLocation
    globals()['DocketEntries'] = DocketEntries
    globals()['Hearings'] = Hearings
    globals()['Judges'] = Judges
    globals()['Parties'] = Parties
    globals()['RelatedCases'] = RelatedCases
    globals()['SourceCaseData'] = SourceCaseData


class Case(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('source_data_status',): {
            'None': None,
            'NO_LONGER_AVAILABLE_IN_COURT': "NO_LONGER_AVAILABLE_IN_COURT",
            'SOURCE_DEPRECATED': "SOURCE_DEPRECATED",
            'NULL': "null",
        },
    }

    validations = {
        ('object',): {
            'max_length': 4,
            'min_length': 4,
        },
        ('case_id',): {
            'max_length': 18,
            'min_length': 18,
        },
        ('url',): {
            'max_length': 500,
        },
        ('case_number',): {
            'max_length': 50,
            'min_length': 3,
        },
        ('case_name',): {
            'max_length': 250,
        },
        ('filed_date',): {
            'max_length': 25,
            'min_length': 25,
        },
        ('court_service_status_id',): {
            'max_length': 18,
            'min_length': 18,
        },
        ('court_service_status_api',): {
            'max_length': 250,
        },
        ('first_fetch_date',): {
            'max_length': 25,
            'min_length': 25,
        },
        ('last_fetch_date',): {
            'max_length': 25,
            'min_length': 25,
        },
        ('last_fetch_date_with_updates',): {
            'max_length': 25,
            'min_length': 25,
        },
        ('participants_last_fetch_date',): {
            'max_length': 25,
            'min_length': 25,
        },
        ('export_api',): {
            'max_length': 255,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = True

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'object': (str,),  # noqa: E501
            'case_id': (str,),  # noqa: E501
            'url': (str, none_type,),  # noqa: E501
            'case_number': (str,),  # noqa: E501
            'case_name': (str, none_type,),  # noqa: E501
            'filed_date': (datetime,),  # noqa: E501
            'has_only_meta_info': (bool,),  # noqa: E501
            'court_service_status_id': (str, none_type,),  # noqa: E501
            'court_service_status_api': (str, none_type,),  # noqa: E501
            'court': (Court,),  # noqa: E501
            'court_location': (CourtLocation,),  # noqa: E501
            'case_type': (CaseType,),  # noqa: E501
            'charge_array': ([CaseCharge],),  # noqa: E501
            'case_status': (CaseStatus,),  # noqa: E501
            'cause_of_action_array': ([CaseCauseOfAction],),  # noqa: E501
            'first_fetch_date': (datetime,),  # noqa: E501
            'last_fetch_date': (datetime,),  # noqa: E501
            'last_fetch_date_with_updates': (datetime,),  # noqa: E501
            'participants_last_fetch_date': (datetime, none_type,),  # noqa: E501
            'source_data_status': (str, none_type,),  # noqa: E501
            'source_case_data': (SourceCaseData,),  # noqa: E501
            'has_documents_with_preview': (bool,),  # noqa: E501
            'export_api': (str,),  # noqa: E501
            'case_stats': (CaseStats,),  # noqa: E501
            'parties': (Parties,),  # noqa: E501
            'attorneys': (Attorneys,),  # noqa: E501
            'judges': (Judges,),  # noqa: E501
            'docket_entries': (DocketEntries,),  # noqa: E501
            'hearings': (Hearings,),  # noqa: E501
            'case_documents': (CaseDocuments,),  # noqa: E501
            'related_cases': (RelatedCases,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'object': 'object',  # noqa: E501
        'case_id': 'caseId',  # noqa: E501
        'url': 'url',  # noqa: E501
        'case_number': 'caseNumber',  # noqa: E501
        'case_name': 'caseName',  # noqa: E501
        'filed_date': 'filedDate',  # noqa: E501
        'has_only_meta_info': 'hasOnlyMetaInfo',  # noqa: E501
        'court_service_status_id': 'courtServiceStatusId',  # noqa: E501
        'court_service_status_api': 'courtServiceStatusAPI',  # noqa: E501
        'court': 'court',  # noqa: E501
        'court_location': 'courtLocation',  # noqa: E501
        'case_type': 'caseType',  # noqa: E501
        'charge_array': 'chargeArray',  # noqa: E501
        'case_status': 'caseStatus',  # noqa: E501
        'cause_of_action_array': 'causeOfActionArray',  # noqa: E501
        'first_fetch_date': 'firstFetchDate',  # noqa: E501
        'last_fetch_date': 'lastFetchDate',  # noqa: E501
        'last_fetch_date_with_updates': 'lastFetchDateWithUpdates',  # noqa: E501
        'participants_last_fetch_date': 'participantsLastFetchDate',  # noqa: E501
        'source_data_status': 'sourceDataStatus',  # noqa: E501
        'source_case_data': 'sourceCaseData',  # noqa: E501
        'has_documents_with_preview': 'hasDocumentsWithPreview',  # noqa: E501
        'export_api': 'exportAPI',  # noqa: E501
        'case_stats': 'caseStats',  # noqa: E501
        'parties': 'parties',  # noqa: E501
        'attorneys': 'attorneys',  # noqa: E501
        'judges': 'judges',  # noqa: E501
        'docket_entries': 'docketEntries',  # noqa: E501
        'hearings': 'hearings',  # noqa: E501
        'case_documents': 'caseDocuments',  # noqa: E501
        'related_cases': 'relatedCases',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, case_id, url, case_number, case_name, filed_date, has_only_meta_info, court_service_status_id, court_service_status_api, court, court_location, case_type, charge_array, case_status, cause_of_action_array, first_fetch_date, last_fetch_date, last_fetch_date_with_updates, participants_last_fetch_date, source_data_status, source_case_data, has_documents_with_preview, export_api, case_stats, parties, attorneys, judges, docket_entries, hearings, case_documents, related_cases, *args, **kwargs):  # noqa: E501
        """Case - a model defined in OpenAPI

        Args:
            case_id (str): Unique identifier of Case.
            url (str, none_type): URL to the case page in UniCourt Application.
            case_number (str): Case number as provided by Court.
            case_name (str, none_type): Case name as provided by Court.
            filed_date (datetime): Filing date for the case provided by the Court. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz
            has_only_meta_info (bool): This field determines if this case object has only meta information. If the value is true and if the full information is required you would need to call the updateCase API.
            court_service_status_id (str, none_type): Court Service Status ID of the requested case where we can use it to get the service status
            court_service_status_api (str, none_type): API to get the service statuses of the given case.
            court (Court):
            court_location (CourtLocation):
            case_type (CaseType):
            charge_array ([CaseCharge]): Array of charges that are added to this case.
            case_status (CaseStatus):
            cause_of_action_array ([CaseCauseOfAction]): Array of cause of Actions that are added to this case.
            first_fetch_date (datetime): The date and time when the case was first fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,.
            last_fetch_date (datetime): The date and time when the case was last fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: It is not necessary that every time the case is fetched from Court we find changes in the case information. It could be that we already have the latest information from the Court and no changes exist.
            last_fetch_date_with_updates (datetime): The date and time when the case was last fetched from the Court where we found changes in the case information. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,
            participants_last_fetch_date (datetime, none_type): The date and time when parties/attorneys were last updated from the Court. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: This is currently applicable for Federal PACER cases since we have an option to exclude parties and fetch only latest docket entries when updating cases to save PACER fees.
            source_data_status (str, none_type): The status of source data of case. If the value of sourceDataStatus is SOURCE_DEPRECATED then it means that the Case has been migrated from old court site to a new court site and the data being shown in the API response is from a old court site. If the sourceDataStatus is NO_LONGER_AVAILABLE_IN_COURT then it means that a particular case is invalid in the court site.
            source_case_data (SourceCaseData):
            has_documents_with_preview (bool): This field will be set to TRUE if atleast one document has a preview.
            export_api (str): When a case is beyond the threshold of entities we provide this link so that the user can request and get all the data of the case with one additional call. This data will be zipped and sent via a webhoook.
            case_stats (CaseStats):
            parties (Parties):
            attorneys (Attorneys):
            judges (Judges):
            docket_entries (DocketEntries):
            hearings (Hearings):
            case_documents (CaseDocuments):
            related_cases (RelatedCases):

        Keyword Args:
            object (str): Name of the object. defaults to "Case"  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        object = kwargs.get('object', "Case")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.object = object
        self.case_id = case_id
        self.url = url
        self.case_number = case_number
        self.case_name = case_name
        self.filed_date = filed_date
        self.has_only_meta_info = has_only_meta_info
        self.court_service_status_id = court_service_status_id
        self.court_service_status_api = court_service_status_api
        self.court = court
        self.court_location = court_location
        self.case_type = case_type
        self.charge_array = charge_array
        self.case_status = case_status
        self.cause_of_action_array = cause_of_action_array
        self.first_fetch_date = first_fetch_date
        self.last_fetch_date = last_fetch_date
        self.last_fetch_date_with_updates = last_fetch_date_with_updates
        self.participants_last_fetch_date = participants_last_fetch_date
        self.source_data_status = source_data_status
        self.source_case_data = source_case_data
        self.has_documents_with_preview = has_documents_with_preview
        self.export_api = export_api
        self.case_stats = case_stats
        self.parties = parties
        self.attorneys = attorneys
        self.judges = judges
        self.docket_entries = docket_entries
        self.hearings = hearings
        self.case_documents = case_documents
        self.related_cases = related_cases
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, case_id, url, case_number, case_name, filed_date, has_only_meta_info, court_service_status_id, court_service_status_api, court, court_location, case_type, charge_array, case_status, cause_of_action_array, first_fetch_date, last_fetch_date, last_fetch_date_with_updates, participants_last_fetch_date, source_data_status, source_case_data, has_documents_with_preview, export_api, case_stats, parties, attorneys, judges, docket_entries, hearings, case_documents, related_cases, *args, **kwargs):  # noqa: E501
        """Case - a model defined in OpenAPI

        Args:
            case_id (str): Unique identifier of Case.
            url (str, none_type): URL to the case page in UniCourt Application.
            case_number (str): Case number as provided by Court.
            case_name (str, none_type): Case name as provided by Court.
            filed_date (datetime): Filing date for the case provided by the Court. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz
            has_only_meta_info (bool): This field determines if this case object has only meta information. If the value is true and if the full information is required you would need to call the updateCase API.
            court_service_status_id (str, none_type): Court Service Status ID of the requested case where we can use it to get the service status
            court_service_status_api (str, none_type): API to get the service statuses of the given case.
            court (Court):
            court_location (CourtLocation):
            case_type (CaseType):
            charge_array ([CaseCharge]): Array of charges that are added to this case.
            case_status (CaseStatus):
            cause_of_action_array ([CaseCauseOfAction]): Array of cause of Actions that are added to this case.
            first_fetch_date (datetime): The date and time when the case was first fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,.
            last_fetch_date (datetime): The date and time when the case was last fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: It is not necessary that every time the case is fetched from Court we find changes in the case information. It could be that we already have the latest information from the Court and no changes exist.
            last_fetch_date_with_updates (datetime): The date and time when the case was last fetched from the Court where we found changes in the case information. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,
            participants_last_fetch_date (datetime, none_type): The date and time when parties/attorneys were last updated from the Court. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: This is currently applicable for Federal PACER cases since we have an option to exclude parties and fetch only latest docket entries when updating cases to save PACER fees.
            source_data_status (str, none_type): The status of source data of case. If the value of sourceDataStatus is SOURCE_DEPRECATED then it means that the Case has been migrated from old court site to a new court site and the data being shown in the API response is from a old court site. If the sourceDataStatus is NO_LONGER_AVAILABLE_IN_COURT then it means that a particular case is invalid in the court site.
            source_case_data (SourceCaseData):
            has_documents_with_preview (bool): This field will be set to TRUE if atleast one document has a preview.
            export_api (str): When a case is beyond the threshold of entities we provide this link so that the user can request and get all the data of the case with one additional call. This data will be zipped and sent via a webhoook.
            case_stats (CaseStats):
            parties (Parties):
            attorneys (Attorneys):
            judges (Judges):
            docket_entries (DocketEntries):
            hearings (Hearings):
            case_documents (CaseDocuments):
            related_cases (RelatedCases):

        Keyword Args:
            object (str): Name of the object. defaults to "Case"  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        object = kwargs.get('object', "Case")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.object = object
        self.case_id = case_id
        self.url = url
        self.case_number = case_number
        self.case_name = case_name
        self.filed_date = filed_date
        self.has_only_meta_info = has_only_meta_info
        self.court_service_status_id = court_service_status_id
        self.court_service_status_api = court_service_status_api
        self.court = court
        self.court_location = court_location
        self.case_type = case_type
        self.charge_array = charge_array
        self.case_status = case_status
        self.cause_of_action_array = cause_of_action_array
        self.first_fetch_date = first_fetch_date
        self.last_fetch_date = last_fetch_date
        self.last_fetch_date_with_updates = last_fetch_date_with_updates
        self.participants_last_fetch_date = participants_last_fetch_date
        self.source_data_status = source_data_status
        self.source_case_data = source_case_data
        self.has_documents_with_preview = has_documents_with_preview
        self.export_api = export_api
        self.case_stats = case_stats
        self.parties = parties
        self.attorneys = attorneys
        self.judges = judges
        self.docket_entries = docket_entries
        self.hearings = hearings
        self.case_documents = case_documents
        self.related_cases = related_cases
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



from unicourt.model.case_document_order_pacer_options import CaseDocumentOrderPacerOptions
from unicourt.model.case_document_order_request import CaseDocumentOrderRequest
from unicourt.sdk.CaseDocuments import CaseDocuments


class TestCaseDocuments:

    def test_get_case_document_download_by_id_with_no_preview():
        return CaseDocuments.get_case_document_download_by_id(
            case_document_id='CDOCaqe42a86394f63',
            is_preview_document=True
        )

    def test_get_case_document_download_by_id_with_preview():
        return CaseDocuments.get_case_document_download_by_id(
            # id with document preview is present
            case_document_id='CDOCagf8a7c8bac76a',
            is_preview_document=True
        )

    # case_document_order_request = CaseDocumentOrderRequest(
    #     case_document_id="CDOCcre989d654fa05",
    #     is_preview_only=True,
    #     pacer_options=CaseDocumentOrderPacerOptions(
    #         pacer_user_id="URKYwer3tyh5r56gq2",
    #         pacer_client_code="Test UniCourt API",
    #     ),
    # )

    def test_order_case_document():
        case_document_order_request = CaseDocumentOrderRequest(
            case_document_id="CDOCcre989d654fa05",
            is_preview_only=True
        )
        return CaseDocuments.order_case_document(
            case_document_order_request=case_document_order_request
        )

    def test_get_case_document_order_callback_by_id():
        case_document_order_request = CaseDocumentOrderRequest(
            case_document_id="CDOCcre989d654fa05",
            is_preview_only=True
        )
        response = CaseDocuments.order_case_document(
            case_document_order_request=case_document_order_request
        )
        cbk_id = response[0]['case_document_order_callback_id']
        return CaseDocuments.get_case_document_order_callback_by_id(
            case_document_order_callback_id=cbk_id
        )

    def test_get_document_by_id():
        return CaseDocuments.get_document_by_id(
            case_document_id='CDOCaqe42a86394f63'
        )

    def test_get_case_document_order_callbacks():
        return CaseDocuments.get_case_document_order_callbacks(
            date='2022-03-08T10:17:56+00:00', status='FAILURE', page_number=1
        )

    def test_get_case_documents():
        return CaseDocuments.get_case_documents(
            case_id='CASEgua4c06e119ea8'
        )



"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.api_client import ApiClient, Endpoint as _Endpoint
from unicourt.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from unicourt.model.case_document import CaseDocument
from unicourt.model.case_document_order_callback import CaseDocumentOrderCallback
from unicourt.model.case_document_order_callback_list_response import CaseDocumentOrderCallbackListResponse
from unicourt.model.case_document_order_request import CaseDocumentOrderRequest
from unicourt.model.case_documents import CaseDocuments
from unicourt.model.document_download import DocumentDownload
from unicourt.model.exception import Exception


class CaseDocumentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_case_document_download_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (DocumentDownload,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseDocumentDownload/{caseDocumentId}',
                'operation_id': 'get_case_document_download_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_document_id',
                    'is_preview_document',
                ],
                'required': [
                    'case_document_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_document_id',
                ]
            },
            root_map={
                'validations': {
                    ('case_document_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_document_id':
                        (str,),
                    'is_preview_document':
                        (bool,),
                },
                'attribute_map': {
                    'case_document_id': 'caseDocumentId',
                    'is_preview_document': 'isPreviewDocument',
                },
                'location_map': {
                    'case_document_id': 'path',
                    'is_preview_document': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_document_order_callback_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (CaseDocumentOrderCallback,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseDocumentOrder/callbacks/{caseDocumentOrderCallbackId}',
                'operation_id': 'get_case_document_order_callback_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_document_order_callback_id',
                ],
                'required': [
                    'case_document_order_callback_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_document_order_callback_id',
                ]
            },
            root_map={
                'validations': {
                    ('case_document_order_callback_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_document_order_callback_id':
                        (str,),
                },
                'attribute_map': {
                    'case_document_order_callback_id': 'caseDocumentOrderCallbackId',
                },
                'location_map': {
                    'case_document_order_callback_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_document_order_callbacks_endpoint = _Endpoint(
            settings={
                'response_type': (CaseDocumentOrderCallbackListResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseDocumentOrder/callbacks',
                'operation_id': 'get_case_document_order_callbacks',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'date',
                    'status',
                    'page_number',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'status',
                ],
                'validation': [
                    'date',
                    'status',
                    'page_number',
                ]
            },
            root_map={
                'validations': {
                    ('date',): {
                        'max_length': 25,
                        'min_length': 25,
                    },
                    ('status',): {
                        'max_length': 11,
                        'min_length': 7,
                    },
                    ('page_number',): {

                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('status',): {

                        "IN_PROGRESS": "IN_PROGRESS",
                        "DELAYED": "DELAYED",
                        "COMPLETE": "COMPLETE",
                        "FAILURE": "FAILURE"
                    },
                },
                'openapi_types': {
                    'date':
                        (datetime,),
                    'status':
                        (str,),
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'date': 'date',
                    'status': 'status',
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'date': 'query',
                    'status': 'query',
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_documents_endpoint = _Endpoint(
            settings={
                'response_type': (CaseDocuments,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/case/{caseId}/documents',
                'operation_id': 'get_case_documents',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_id',
                    'in_library',
                    'after_first_fetch_date',
                    'library_date',
                    'first_fetch_date',
                    'sort_by',
                    'page_number',
                ],
                'required': [
                    'case_id',
                ],
                'nullable': [
                    'after_first_fetch_date',
                    'library_date',
                    'first_fetch_date',
                ],
                'enum': [
                    'sort_by',
                ],
                'validation': [
                    'case_id',
                    'after_first_fetch_date',
                    'library_date',
                    'first_fetch_date',
                    'sort_by',
                ]
            },
            root_map={
                'validations': {
                    ('case_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                    ('after_first_fetch_date',): {
                        'max_length': 25,
                        'min_length': 25,
                    },
                    ('library_date',): {
                        'max_length': 25,
                        'min_length': 25,
                    },
                    ('first_fetch_date',): {
                        'max_length': 25,
                        'min_length': 25,
                    },
                    ('sort_by',): {
                        'max_length': 20,
                        'min_length': 10,
                    },
                },
                'allowed_values': {
                    ('sort_by',): {

                        "LATEST_TO_OLDEST": "latest to oldest",
                        "OLDEST_TO_LATEST": "oldest to latest"
                    },
                },
                'openapi_types': {
                    'case_id':
                        (str,),
                    'in_library':
                        (bool,),
                    'after_first_fetch_date':
                        (datetime, none_type,),
                    'library_date':
                        (datetime, none_type,),
                    'first_fetch_date':
                        (datetime, none_type,),
                    'sort_by':
                        (str,),
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'case_id': 'caseId',
                    'in_library': 'inLibrary',
                    'after_first_fetch_date': 'afterFirstFetchDate',
                    'library_date': 'libraryDate',
                    'first_fetch_date': 'firstFetchDate',
                    'sort_by': 'sortBy',
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'case_id': 'path',
                    'in_library': 'query',
                    'after_first_fetch_date': 'query',
                    'library_date': 'query',
                    'first_fetch_date': 'query',
                    'sort_by': 'query',
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_document_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (CaseDocument,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseDocument/{caseDocumentId}',
                'operation_id': 'get_document_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_document_id',
                ],
                'required': [
                    'case_document_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_document_id',
                ]
            },
            root_map={
                'validations': {
                    ('case_document_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_document_id':
                        (str,),
                },
                'attribute_map': {
                    'case_document_id': 'caseDocumentId',
                },
                'location_map': {
                    'case_document_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.order_case_document_endpoint = _Endpoint(
            settings={
                'response_type': (CaseDocumentOrderCallback,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseDocumentOrder',
                'operation_id': 'order_case_document',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_document_order_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_document_order_request':
                        (CaseDocumentOrderRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'case_document_order_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_case_document_download_by_id(
        self,
        case_document_id,
        **kwargs
    ):
        """Gets downloadable URL for a requested Document ID.  # noqa: E501

        Gets downloadable URL for a requested Document ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_document_download_by_id(case_document_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_document_id (str): Document ID which you want to download.

        Keyword Args:
            is_preview_document (bool): If the document you want to download is a preview of a document.. [optional] if omitted the server will use the default value of False
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DocumentDownload
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_document_id'] = \
            case_document_id
        return self.get_case_document_download_by_id_endpoint.call_with_http_info(**kwargs)

    def get_case_document_order_callback_by_id(
        self,
        case_document_order_callback_id,
        **kwargs
    ):
        """Get Case Document Order Callback for a requested Case Document Order Callback Id.  # noqa: E501

        Get Case Document Order Callback for a requested Case Document Order Callback Id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_document_order_callback_by_id(case_document_order_callback_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_document_order_callback_id (str): Unique Id for the Case Document Order Callback.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseDocumentOrderCallback
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_document_order_callback_id'] = \
            case_document_order_callback_id
        return self.get_case_document_order_callback_by_id_endpoint.call_with_http_info(**kwargs)

    def get_case_document_order_callbacks(
        self,
        **kwargs
    ):
        """Get Case Document Order Callback list for a requested Date.  # noqa: E501

        Get Case Document Order Callback list for a requested Date.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_document_order_callbacks(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            date (datetime): Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.. [optional]
            status (str): Status of Document Order callbacks. Default status will fetch all callbacks.. [optional]
            page_number (int): Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 . [optional] if omitted the server will use the default value of 1
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseDocumentOrderCallbackListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_case_document_order_callbacks_endpoint.call_with_http_info(**kwargs)

    def get_case_documents(
        self,
        case_id,
        **kwargs
    ):
        """Gets Documents for a requested Case ID.  # noqa: E501

        Gets Documents for a requested Case ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_documents(case_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_id (str): Case ID for which you want the data for.

        Keyword Args:
            in_library (bool): Filter all the documents those are added to the UniCourt library.. [optional]
            after_first_fetch_date (datetime, none_type): Get all the documents which were added to the case on or after a specific date.. [optional]
            library_date (datetime, none_type): Sort all the documents based on the date when the document was added to the UniCourt Library.. [optional]
            first_fetch_date (datetime, none_type): Sort all the documents based on the date it was fetched from the source site.. [optional]
            sort_by (str): Sort documents with document order.. [optional]
            page_number (int): The page for which the result should be retrieved.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseDocuments
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_id'] = \
            case_id
        return self.get_case_documents_endpoint.call_with_http_info(**kwargs)

    def get_document_by_id(
        self,
        case_document_id,
        **kwargs
    ):
        """Gets details for a requested Document ID.  # noqa: E501

        Gets details for a requested Document ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_by_id(case_document_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_document_id (str): Specific Case Dcoument ID for which you want the data for.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseDocument
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_document_id'] = \
            case_document_id
        return self.get_document_by_id_endpoint.call_with_http_info(**kwargs)

    def order_case_document(
        self,
        **kwargs
    ):
        """Add Case Document Order for requested Document Ids.  # noqa: E501

        Add Case Document Order for requested Document Ids. The status will be ``IN_PROGRESS`` after it has been requested. If the request is not processed within 4 hours, it will be reported as ``DELAYED``.  If the request is still incomplete after 4 hours, it will remain in the DELAYED status for up to 72 hours after the request was approved. Such requests will be recorded as ``TIMEOUT`` after 72 hours.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.order_case_document(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            case_document_order_request (CaseDocumentOrderRequest): If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseDocumentOrderCallback
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.order_case_document_endpoint.call_with_http_info(**kwargs)




from unicourt.api.case_tracking_api import CaseTrackingApi
from unicourt import utils
class CaseTracking:

    @staticmethod
    def get_case_track_by_id(
        case_id,
        **kwargs
    ):

        """Get Case Track for a requested Case Id.  


        Retrieve case tracking information for the specified caseId value.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseTrackingApi(api_client).get_case_track_by_id(
        case_id,
        **kwargs
    )

    @staticmethod
    def get_case_tracks(
        **kwargs
    ):

        """Get Case Track list.  


        Retrieve a list of all tracked cases.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseTrackingApi(api_client).get_case_tracks(
        **kwargs
    )

    @staticmethod
    def remove_case_track_by_id(
        case_id,
        **kwargs
    ):

        """Remove Case Track for a specific Case Id.  


        Remove Case Track for a specific Case Id.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseTrackingApi(api_client).remove_case_track_by_id(
        case_id,
        **kwargs
    )

    @staticmethod
    def track_case(
        **kwargs
    ):

        """Add Case Track for the requested Case Id.  


        Track the specified case.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseTrackingApi(api_client).track_case(
        **kwargs
    )



import unicourt
from unicourt.api.authentication_api import AuthenticationApi
from unicourt.model.access_token_request import AccessTokenRequest
from unicourt.model.invalidate_access_token_request import InvalidateAccessTokenRequest
from unicourt import utils


class Authentication(object):

    def update_api_client_after_login():
        """
        This method is used to update the api_client object after 
        the generate_new_token is called so that we can use the same 
        api client for rest of the api calls.
        """
        unicourt.configuration = unicourt.Configuration(
            access_token=unicourt.ACCESS_TOKEN)
        unicourt.api_client = unicourt.ApiClient(unicourt.configuration)

    def generate_new_token(client_id=None, client_secret=None):
        """Generate new token to access API. 
        Generate new access token, UniCourt provides clientId and client Secret. 
        Each time you will get new Access token. At a time you can have max 10 access tokens. 
        There will not be any expiry for access token. If you request for more than 10 tokens you will get error message.
        """
        with utils.api_client() as api_client:
            unicourt.CLIENT_ID = client_id or unicourt.CLIENT_ID
            unicourt.CLIENT_SECRET = client_secret or unicourt.CLIENT_SECRET
            payload = AccessTokenRequest(
                client_id=unicourt.CLIENT_ID,
                client_secret=unicourt.CLIENT_SECRET,
            )
            response, status = AuthenticationApi(api_client).generate_new_token(
                access_token_request=payload)
            unicourt.ACCESS_TOKEN = response.access_token
            unicourt.TOKEN_ID = response.token_id
            Authentication.update_api_client_after_login()
        return response, status

    def invalidate_token(client_id=None, client_secret=None, token_id=None):
        """API to invalidate all access tokens.  
        Logout API to invalidate all access tokens.
        """
        invalidate_access_token_request = InvalidateAccessTokenRequest(
            client_id=client_id or unicourt.CLIENT_ID,
            client_secret=client_secret or unicourt.CLIENT_SECRET,
            token_id=token_id or unicourt.TOKEN_ID
        )
        with utils.api_client() as api_client:
            return AuthenticationApi(api_client).invalidate_token(
                invalidate_access_token_request=invalidate_access_token_request)

    def invalidate_all_tokens(client_id=None, client_secret=None):
        """API to invalidate the access token.  # noqa: E501
        API to invalidate the access token
        """
        access_token_request = AccessTokenRequest(
            client_id=unicourt.CLIENT_ID,
            client_secret=unicourt.CLIENT_SECRET,
        )
        with utils.api_client() as api_client:
            return AuthenticationApi(api_client).invalidate_all_tokens(
                access_token_request=access_token_request)

    def list_all_token_ids(client_id=None, client_secret=None):
        """API to list all the access tokens Id. 
        API to list all the access tokens Id.
        """
        access_token_request = AccessTokenRequest(
            client_id=unicourt.CLIENT_ID,
            client_secret=unicourt.CLIENT_SECRET,
        )
        with utils.api_client() as api_client:
            return AuthenticationApi(api_client).list_all_token_ids(
                access_token_request=access_token_request)



from unicourt.api.pacer_credential_api import PACERCredentialApi
from unicourt import utils
class PACERCredential:

    @staticmethod
    def add_pacer_credential(
        **kwargs
    ):

        """Add Pacer Credential.  


        Register PACER credentials with UniCourt.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).add_pacer_credential(
        **kwargs
    )

    @staticmethod
    def get_pacer_credential(
        **kwargs
    ):

        """Get Pacer Credential List.  


        List registered PACER credentials.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).get_pacer_credential(
        **kwargs
    )

    @staticmethod
    def get_pacer_credential_by_id(
        pacer_user_id,
        **kwargs
    ):

        """Get Pacer Credential for a requested pacer User Id.  


        Retrieve the PACER credentials for the specified PACER username.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).get_pacer_credential_by_id(
        pacer_user_id,
        **kwargs
    )

    @staticmethod
    def remove_pacer_credential_by_id(
        pacer_user_id,
        **kwargs
    ):

        """Remove Pacer credential for a specific Pacer User Id.  


        De-register the PACER credentials for the specified PACER username.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return PACERCredentialApi(api_client).remove_pacer_credential_by_id(
        pacer_user_id,
        **kwargs
    )



"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.api_client import ApiClient, Endpoint as _Endpoint
from unicourt.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from unicourt.model.billing_cycle_usage_response import BillingCycleUsageResponse
from unicourt.model.billing_cycles_response import BillingCyclesResponse
from unicourt.model.daily_usage_response import DailyUsageResponse
from unicourt.model.exception import Exception


class UsageApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_billing_cycles_endpoint = _Endpoint(
            settings={
                'response_type': (BillingCyclesResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/billingCycles',
                'operation_id': 'get_billing_cycles',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_billing_usage_by_billing_cycle_endpoint = _Endpoint(
            settings={
                'response_type': (BillingCycleUsageResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/billingCycleUsage/{billingCycle}',
                'operation_id': 'get_billing_usage_by_billing_cycle',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'billing_cycle',
                ],
                'required': [
                    'billing_cycle',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'billing_cycle',
                ]
            },
            root_map={
                'validations': {
                    ('billing_cycle',): {
                        'max_length': 22,
                        'min_length': 22,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'billing_cycle':
                        (str,),
                },
                'attribute_map': {
                    'billing_cycle': 'billingCycle',
                },
                'location_map': {
                    'billing_cycle': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_daily_usage_by_date_endpoint = _Endpoint(
            settings={
                'response_type': (DailyUsageResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/dailyUsage/{date}',
                'operation_id': 'get_daily_usage_by_date',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'date',
                ],
                'required': [
                    'date',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'date',
                ]
            },
            root_map={
                'validations': {
                    ('date',): {
                        'max_length': 10,
                        'min_length': 10,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'date':
                        (date,),
                },
                'attribute_map': {
                    'date': 'date',
                },
                'location_map': {
                    'date': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_billing_cycles(
        self,
        **kwargs
    ):
        """Get all the previous 12 billing cycles.  # noqa: E501

        An endpoint to obtain information on the previous 12 billing cycles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_billing_cycles(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            BillingCyclesResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_billing_cycles_endpoint.call_with_http_info(**kwargs)

    def get_billing_usage_by_billing_cycle(
        self,
        billing_cycle,
        **kwargs
    ):
        """Specify the billing cycle to know the API usage.  # noqa: E501

        An endpoint to obtain information on API usage for a specific billing cycle.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_billing_usage_by_billing_cycle(billing_cycle, async_req=True)
        >>> result = thread.get()

        Args:
            billing_cycle (str): The date obtainable from the /billingCycles endpoint which is used as an identifier for the specific billing cycle you wish to obtain information on.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            BillingCycleUsageResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['billing_cycle'] = \
            billing_cycle
        return self.get_billing_usage_by_billing_cycle_endpoint.call_with_http_info(**kwargs)

    def get_daily_usage_by_date(
        self,
        date,
        **kwargs
    ):
        """Get API usage for a requested Date.  # noqa: E501

        An endpoint to obtain information on API usage for a specific day.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_daily_usage_by_date(date, async_req=True)
        >>> result = thread.get()

        Args:
            date (date): The specific date for which you wish to obtain information on API usage.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DailyUsageResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['date'] = \
            date
        return self.get_daily_usage_by_date_endpoint.call_with_http_info(**kwargs)

